% Using the sim150 Matlab class.

% You always need to create an instance of the robot before you
% use it; it is implemented as a singleton so that there is only
% ever one valid instance.
% r is the robot
r = sim150.instance()

% You can get a summary of the available methods by asking for help
help sim150

help sim150.ready
r.ready()

% You can use getpose to get the pose matrix and joint values.
help sim150.getpose
[T, J, dh] = r.getpose()

% It is important to note that the robot does not use the
% Denavit-Hartenberg convention in its native API. Joints
% 2, 3, and 4 are measured relative to the horizon.
% Analyze the angles in J returned by the previous command
% and confirm that J(2), J(3), and J(4) are what you expect
% if you were measuring these values relative to the horizon.

% You can adjust the joint angles using the command madeg:
help sim150.madeg

% Adjust the shoulder angle to be 45 degrees up relative to
% the horizon:
Jdeg = [0 45 0 0 0];
r.madeg(Jdeg);

% Adjust the shoulder angle to be 0 degrees relative to the
% horizon and the wrist angle to be 90 degrees down relative to the
% horizon:
Jdeg = [0 0 0 -90 0];
r.madeg(Jdeg);

% Adjust the shoulder angle to be 0 degrees relative to the
% horizon, the elbow angle to be -30 degrees down relative to the
% horizon, and the wrist angle to be 0 degrees relative to the
% horizon:
Jdeg = [0 0 -30 -0 0];
r.madeg(Jdeg);

% Back to the ready position:
r.ready();

% Turn the waist 90 degrees, but leave the other joints fixed:
Jdeg = [90 90 0 0 0];
r.madeg(Jdeg);

% Now spin the wrist by 90 degrees, but leave the other joints fixed:
Jdeg = [90 90 0 0 90];
r.madeg(Jdeg);

% Back to the ready position:
r.ready();

% If you want the DH convention then you must use the dhmadeg
% command.
help sim150.dhmadeg
Jdeg = [90 90 -90 0 90];
r.dhmadeg(Jdeg);

% Opening and closing the gripper
r.open()
r.close()

r.ready()

% Always quit
help sim150.quit
r.quit()


